==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.discovery/src/org/netbeans/modules/cnd/discovery/api/DiscoveryProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.cnd.discovery.api;

import java.util.List;
import org.netbeans.modules.cnd.support.Interrupter;
import org.openide.util.Cancellable;

/**
 *
 * @author Alexander Simon
 */
public interface DiscoveryProvider extends Cancellable {

    /**
     * Returns provider ID
     */
    String getID();
    
    /**
     * Returns provider name
     */
    String getName();

    /**
     * Returns provider description
     */
    String getDescription();
    
    /**
     * Returns property keys of additional information for provider
     */
    List<String> getPropertyKeys();

    /**
     * Returns property of additional information for provider
     */
    ProviderProperty getProperty(String key);
    
    /**
     * Clean provider state
     */
   void clean();

    /**
     * Is analyzer applicable to project
     */
    boolean isApplicable(ProjectProxy project);

    /**
     * Can analyze project. Returns weight of assurance of results.
     * Results range is [0,100].
     * 0 provider is not sure about results at all
     * 100 provider is sure about results
     */
    DiscoveryExtensionInterface.Applicable canAnalyze(ProjectProxy project, Interrupter interrupter);

    /**
     * Analyze project and returns list of configuration
     */
    public List<Configuration> analyze(ProjectProxy project, Progress progress, Interrupter interrupter);
    
    /**
     * Stop analyzing.
     */
    @Override
    boolean cancel();
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/cnd.discovery/src/org/netbeans/modules/cnd/discovery/api/DiscoveryProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.cnd.discovery.api;

import java.util.List;
import org.netbeans.modules.cnd.support.Interrupter;
import org.openide.util.Cancellable;

/**
 *
 * @author Alexander Simon
 */
public interface DiscoveryProvider extends Cancellable {

    /**
     * @return provider ID
     */
    String getID();
    
    /**
     * @return provider name
     */
    String getName();

    /**
     * @return provider description
     */
    String getDescription();
    
    /**
     * @return property keys of additional information for provider
     */
    List<String> getPropertyKeys();

    /**
     * @param key property name
     * 
     * @return property of additional information for provider
     */
    ProviderProperty getProperty(String key);
    
    /**
     * @param project proxy project
     * 
     * @return true if analyzer is applicable to project
     */
    boolean isApplicable(ProjectProxy project);

    /**
     * Can analyze project. Returns weight of assurance of results.
     * Results range is [0,100].
     * 0 provider is not sure about results at all
     * 100 provider is sure about results
     * 
     * @param project project proxy
     * @param interrupter interrupter
     * 
     * @return is analyzer applicable to project
     */
    DiscoveryExtensionInterface.Applicable canAnalyze(ProjectProxy project, Interrupter interrupter);

    /**
     * @param project project proxy
     * @param progress progress
     * @param interrupter interrupter
     * 
     * @return analyzes project and returns list of configuration
     */
    public List<Configuration> analyze(ProjectProxy project, Progress progress, Interrupter interrupter);
    
    /**
     * Stop analyzing.
     */
    @Override
    boolean cancel();
}
